# AI-Voice

## Usage:

To use AI-Voice, use the AiVoice(text, key) command.

In this command, text is the text you want to use, and key is your API key, which you can get from here: https://rapidapi.com/k_1/api/large-text-to-speech/

The output of this command is saved as a wave file called output in the directory you called from.
